@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006010';
+our $VERSION   = '0.006011';
 
 has _order =>
   is            => rw,
@@ -411,8 +411,7 @@ sub _compile_default {
 
     if ( $self->has_coderef_default ) {
         my $var = $self->coderef_default_variable;
-        return sprintf 'do { my $method = %s; %s->$method }',
-          $var, $selfvar;
+        return sprintf '%s->( %s )', $var, $selfvar;
     }
     elsif ( $self->has_inline_default ) {
         return ${ $self->default };
@@ -452,6 +451,11 @@ sub _compile_clone {
         $selfvar, $self->_expand_name( $self->cloner_method ), $self->_q( $self->name ), $valuevar;
 }
 
+sub _sanitize_identifier {
+    ( my $str = pop ) =~ s/([_\W])/$1 eq '_' ? '__' : sprintf('_%x', ord($1))/ge;
+    $str;
+}
+
 sub compile_init {
     my ( $self, $selfvar, $argvar ) = @_;
 
@@ -462,8 +466,11 @@ sub compile_init {
     if ( defined $init_arg ) {
 
         if ( my @alias = $self->_all_aliases ) {
-            push @code, sprintf 'for my $alias ( %s ) { last if exists %s->{%s}; next if !exists %s->{$alias}; %s->{%s} = %s->{$alias} } ',
-                $self->_q( @alias ), $argvar, $self->_q_init_arg, $argvar, $argvar, $self->_q_init_arg, $argvar;
+            my $new_argvar = "\$args_for_" . $self->_sanitize_identifier( $self->name );
+            push @code, sprintf( 'my %s = {};', $new_argvar );
+            push @code, sprintf 'for ( %s, %s ) { next unless exists %s->{$_}; %s->{%s} = %s->{$_}; last; }',
+                $self->_q_init_arg, $self->_q( @alias ), $argvar, $new_argvar, $self->_q_init_arg, $argvar;
+            $argvar = $new_argvar;
         }
 
         my $code;
@@ -476,10 +483,24 @@ sub compile_init {
         }
 
         if ( $self->has_default || $self->has_builder and not $self->lazy ) {
-            $code .= sprintf 'do { my $value = exists( %s ) ? %s : %s; ',
-                $valuevar, $valuevar, $self->_compile_default( $selfvar );
-            $valuevar = '$value';
-            $postamble = "}; $postamble";
+            if ( $self->type ) {
+                $code .= sprintf 'do { my $value = exists( %s ) ? %s : %s; ',
+                    $valuevar, $valuevar, $self->_compile_default( $selfvar );
+                $valuevar = '$value';
+                $postamble = "}; $postamble";
+            }
+            else {
+                $valuevar = sprintf '( exists( %s ) ? %s : %s )',
+                    $valuevar, $valuevar, $self->_compile_default( $selfvar );
+            }
+
+            my $trigger_code = $self->trigger
+                ? $self->_compile_trigger(
+                    $selfvar,
+                    sprintf( '%s->{%s}', $selfvar, $self->_q_name ),
+                ) . sprintf( ' if exists %s->{%s}; ', $argvar, $self->_q_init_arg )
+                : '';
+            $postamble = $trigger_code . $postamble;
         }
         elsif ( $self->required and not $self->lazy ) {
             push @code, sprintf '%s "Missing key in constructor: %s" unless exists %s; ',
