@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.006010";
+    our $MITE_VERSION = "0.006011";
 
     BEGIN {
         require Scalar::Util;
@@ -45,10 +45,9 @@
         # Attribute: attributes
         do {
             my $value =
-              exists( $args->{"attributes"} ) ? $args->{"attributes"} : do {
-                my $method = $Mite::Role::__attributes_DEFAULT__;
-                $self->$method;
-              };
+              exists( $args->{"attributes"} )
+              ? $args->{"attributes"}
+              : $Mite::Role::__attributes_DEFAULT__->($self);
             do {
 
                 package Mite::Shim;
@@ -251,10 +250,10 @@
 
         # Attribute: extends
         do {
-            my $value = exists( $args->{"extends"} ) ? $args->{"extends"} : do {
-                my $method = $Mite::Class::__extends_DEFAULT__;
-                $self->$method;
-            };
+            my $value =
+              exists( $args->{"extends"} )
+              ? $args->{"extends"}
+              : $Mite::Class::__extends_DEFAULT__->($self);
             do {
 
                 package Mite::Shim;
@@ -288,6 +287,8 @@
               or croak "Type check failed in constructor: %s should be %s",
               "extends", "ArrayRef[ValidClassName]";
             $self->{"extends"} = $value;
+            $self->_trigger_extends( $self->{"extends"} )
+              if exists $args->{"extends"};
         };
 
         # Attribute: parents
