@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.006010";
+    our $MITE_VERSION = "0.006011";
 
     BEGIN {
         require Scalar::Util;
@@ -211,11 +211,9 @@
                 exists( $_[0]{"file"} ) ? $_[0]{"file"} : (
                     $_[0]{"file"} = do {
                         my $default_value = do {
-                            my $to_coerce = do {
-                                my $method =
-                                  $Mite::Compiled::__file_DEFAULT__;
-                                $_[0]->$method;
-                            };
+                            my $to_coerce =
+                              $Mite::Compiled::__file_DEFAULT__->(
+                                $_[0] );
                             (
                                 (
                                     do {
